==> tof-1.6.tar.gz: tof-1.6/tof_auth.php <==
<?php

class Tof_Auth extends Auth {
  var $classname        = "Tof_Auth"; // Object serialization support
  var $lifetime         =  10000000;
       
  // DB_Sql subclass and database table to use
  var $database_class = "MyDB_Sql";
  var $database_table = "users";

  // Some magic value to make our uids harder to guess.
  var $magic = "Abracadabra_tux";

  var $name;
  var $email;
  var $uid;

  var $nobody = true;

  function auth_loginform($failure=false) {
    global $sess;
    include("loginform.ihtml");
  }

  function auth_validatelogin() {
    global $username, $password, $uid;    // form variables from loginform.ihtml
        
    // If authentication fails, loginform.html will
    // find $this->auth["uname"] set and use it.
    $this->auth["uname"]=$username;
       
    // Value to return in case auth fails.
    $uid   = false;

    // Check the database for this user and password pair.
    $query = sprintf(
        "select UserID,Name,Email from %s where Username = '%s' and Password = '%s'",
        $this->database_table,
        addslashes($username),
        addslashes($password)
    );
    $this->db->query($query);
         
    // If we found a matching user, grab the uid and permissions...
    while($this->db->next_record()) {
		// Required.
		$this->uid = $this->db->f("userid");
		$uid = $this->uid;
		$this->name = $this->db->f("name");
		$this->email = $this->db->f("email");
		if ($uid=="") {
			echo "<strong>ERREUR : UID VIDE</strong>";
		}
    }
    return $uid;
  }

}?>

==> tof-1.6.1.tar.gz: tof-1.6.1/tof_auth.php <==
<?php

class Tof_Auth extends Auth {
  var $classname        = "Tof_Auth"; // Object serialization support
  var $lifetime         =  10000000;
       
  // DB_Sql subclass and database table to use
  var $database_class = "MyDB_Sql";
  var $database_table = "users";

  // Some magic value to make our uids harder to guess.
  var $magic = "Abracadabra_tux";

  var $name;
  var $email;
  var $uid;

  var $nobody = true;

  function auth_loginform($failure=false) {
    global $sess;
    include("loginform.ihtml");
  }

  function auth_validatelogin() {
    global $uid;    // form variables from loginform.ihtml
	$username = $_REQUEST['username'];
	$password = $_REQUEST['password'];
    // If authentication fails, loginform.html will
    // find $this->auth["uname"] set and use it.
    $this->auth["uname"]=$username;
       
    // Value to return in case auth fails.
    $uid   = false;

    // Check the database for this user and password pair.
    $query = sprintf(
        "select UserID,Name,Email from %s where Username = '%s' and Password = '%s'",
        $this->database_table,
        addslashes($username),
        addslashes($password)
    );
    $this->db->query($query);
         
    // If we found a matching user, grab the uid and permissions...
    while($this->db->next_record()) {
		// Required.
		$this->uid = $this->db->f("userid");
		$uid = $this->uid;
		$this->name = $this->db->f("name");
		$this->email = $this->db->f("email");
		if ($uid=="") {
			echo "<strong>ERREUR : UID VIDE</strong>";
		}
    }
    return $uid;
  }

}?>
